#
# spec file for package python-pytest-mpl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-mpl
Version:        0.17.0
Release:        2.2
Summary:        Pytest plugin for testing Matplotlib figures
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/matplotlib/pytest-mpl
# get the test reference data from the GitHub archive
Source:         https://github.com/matplotlib/pytest-mpl/archive/v%{version}.tar.gz#/pytest-mpl-%{version}-gh.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-Pillow
Requires:       python-matplotlib
Requires:       python-packaging
Requires:       python-pytest
%if %python_version_nodots < 39
Requires:       python-importlib-resources
%endif
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module importlib-resources if %python-base < 3.9}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This is a pytest plugin to help with testing figures output from Matplotlib.

%prep
%setup -q -n pytest-mpl-%{version}

%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# not the right path setup in obs build environment
donttest="(test_generate_summary and test_config)"
%pytest -k "not ($donttest)"

%files %{python_files}
%doc CHANGES.md README.rst
%license LICENSE
%{python_sitelib}/pytest_mpl
%{python_sitelib}/pytest_mpl-%{version}.dist-info

%changelog
* Mon Sep 23 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sat Aug 17 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.17.0
  [#]# Fixes
  * Improve Logging Configuration: don't modify root logger by
    @theOehrly in #182
  * Improve error reporting when test raises an exception by
    @ConorMacBride in #193
  * MNT: Compat with pytest 8.1 by @pllim in #219
  [#]# Exciting New Features
  * Added support for EPS, PDF, and SVG image comparison by
    @astrofrog in #194
  * Started implementing support for deterministic figure output by
    @astrofrog in #196
  * Add missing CLI and INI options for a consistent API by
    @astrofrog in #181
  * Avoid using py.path by @eerovaher in #207
  * Allow using -p no:legacypath with pytest >= 7 by @eerovaher in
    [#213]
  [#]# Other Changes
  * Add initial Sphinx docs by @ConorMacBride in #174
  * Add documentation on avoiding PytestReturnNotNoneWarning by
    @ConorMacBride in #185
  * Add RTD config by @ConorMacBride in #195
  * Migrate docs from README.rst to website by @ConorMacBride in
    [#199]
  * Set deterministic to True for vector graphics and warn about
    change to True in future for PNG by @astrofrog in #197
  [#]# Infrastructure Changes
  * Verify class-based testing configurations produce the expected
    results by @ConorMacBride in #175
  * Update testing and CI for Matplotlib v3.6 by @ConorMacBride in
    [#184]
  * Upgrade for tox 4 by @ConorMacBride in #191
  * Upgrade CI package versions by @ConorMacBride in #215
  * Test wheel with 3.11 until python-dateutil is updated for 3.12
    by @ConorMacBride in #217
  * Fix unclosed test files by @ConorMacBride in #222
- Release 0.16
  [#]# Fixes
  * Make summary log message about test results in general instead
    of failures by @neutrinoceros in #148
  * Add support for classes with pytest 7 by @ConorMacBride in #164
  * Note that this change necessitated a minor breaking change for
    figure tests within classes only, and the following will need
    to be done:
  - Hash library test names will need to be regenerated/updated
    to include the class name.
  - If the undocumented mpl-use-full-test-name ini option is
    enabled, the the baseline images will need to be regenerated,
    or have their filename updated to include the class name.
  [#]# Other Changes
  * Improve parametrized test names in HTML summaries by
    @ConorMacBride in #165
  * Improve tests/subtests by @ConorMacBride in #163
- Release 0.15
  [#]# Features
  * Remove Python 2 from package classifiers by @dopplershift in
    [#137]
  * Downloadable hash library in HTML summary by @ConorMacBride in
    [#138]
  [#]# Fixes
  * No need to warn when falling back to other URL by @pllim in
    [#139]
- Not worth mentioning changes before 0.15
* Wed Feb 17 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.12
  * Fix passing a https url for baseline images from the CLI. [#89]
  * Added --mpl-baseline-relative option to specify baseline
    images relative to the test path. [#96]
  * Add option to do comparisons against a json library of sha256
    hashes. [#98]
  * Drop support for matplotlib 1.5 and Python < 3.6. [#100]
  * Add support for generating a HTML summary of test faliures.
    [#101]
  * Add support for falling back to baseline image comparison if
    hash comparison fails. [#101]
- Skip python2 and python36 flavors. python36-matplotlib is no
  longer in Tumbleweed (NEP 29)
- Get test reference data from GitHub archive
* Mon Aug  3 2020 Matej Cepl <mcepl@suse.com>
- Nose is actually not needed (gh#matplotlib/pytest-mpl#25).
* Mon Nov 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.11:
  * Improve error message if image shapes don't match. [#79]
  * Properly register mpl_image_compare marker with pytest. [#83]
* Thu Jan 17 2019 Todd R <toddrme2178@gmail.com>
- Initial version
